# hopeit.engine apps-visualizer plugin


This library is part of hopeit.engine:

> check: https://github.com/hopeit-git/hopeit.engine


### Install using hopeit.engine extras [apps-visualizer]:

```
pip install hopeit.engine[apps-visualizer]
```

### Include plugin configuration file when running `hopeit_server` in addition to your existing config files.

```
hopeit_server ... --config-files=...,plugins/ops/apps-visualizer/config/plugin-config.json,...
```

### Visualize App events diagram using url:

```
http://host:port/ops/apps-visualizer/events-graph
```
